@@ -1,7 +1,7 @@
 package Unix::Passwd::File;
 
 our $DATE = '2015-07-01'; # DATE
-our $VERSION = '0.19'; # VERSION
+our $VERSION = '0.20'; # VERSION
 
 use 5.010001;
 use strict;
@@ -1224,6 +1224,7 @@ $SPEC{add_group} = {
         },
         gid => {
             summary => 'Pick a specific new GID',
+            schema => 'int*',
             description => <<'_',
 
 Adding a new group with duplicate GID is allowed.
@@ -1275,6 +1276,7 @@ $SPEC{add_user} = {
         group => {
             summary => 'Select primary group '.
                 '(default is group with same name as user)',
+            schema => 'str*',
             description => <<'_',
 
 Normally, a user's primary group with group with the same name as user, which
@@ -1287,6 +1289,7 @@ _
         },
         gid => {
             summary => 'Pick a specific GID when creating group',
+            schema => 'int*',
             description => <<'_',
 
 Duplicate GID is allowed.
@@ -1295,12 +1298,15 @@ _
         },
         min_gid => {
             summary => 'Pick a range for GID when creating group',
+            schema => 'int*',
         },
         max_gid => {
             summary => 'Pick a range for GID when creating group',
+            schema => 'int*',
         },
         uid => {
             summary => 'Pick a specific new UID',
+            schema => 'int*',
             description => <<'_',
 
 Adding a new user with duplicate UID is allowed.
@@ -1939,7 +1945,7 @@ Unix::Passwd::File - Manipulate /etc/{passwd,shadow,group,gshadow} entries
 
 =head1 VERSION
 
-This document describes version 0.19 of Unix::Passwd::File (from Perl distribution Unix-Passwd-File), released on 2015-07-01.
+This document describes version 0.20 of Unix::Passwd::File (from Perl distribution Unix-Passwd-File), released on 2015-07-01.
 
 =head1 SYNOPSIS
 
@@ -2081,7 +2087,7 @@ will not be backed up. Previous backup will be overwritten.
 
 Specify location of passwd files.
 
-=item * B<gid> => I<any>
+=item * B<gid> => I<int>
 
 Pick a specific new GID.
 
@@ -2152,13 +2158,13 @@ The date of expiration of the account, expressed as the number of days since Jan
 
 Usually, it contains the full username.
 
-=item * B<gid> => I<any>
+=item * B<gid> => I<int>
 
 Pick a specific GID when creating group.
 
 Duplicate GID is allowed.
 
-=item * B<group> => I<any>
+=item * B<group> => I<str>
 
 Select primary group (default is group with same name as user).
 
@@ -2175,7 +2181,7 @@ User's home directory.
 
 The date of the last password change, expressed as the number of days since Jan 1, 1970.
 
-=item * B<max_gid> => I<any>
+=item * B<max_gid> => I<int>
 
 Pick a range for GID when creating group.
 
@@ -2190,7 +2196,7 @@ Pick a range for new UID.
 If a free UID between C<min_uid> and C<max_uid> is not found, error 412 is
 returned.
 
-=item * B<min_gid> => I<any>
+=item * B<min_gid> => I<int>
 
 Pick a range for GID when creating group.
 
@@ -2221,7 +2227,7 @@ The number of days before a password is going to expire (see max_pass_age) durin
 
 User's shell.
 
-=item * B<uid> => I<any>
+=item * B<uid> => I<int>
 
 Pick a specific new UID.
 
